<?php global $CONF;

// --------------------------------------------
// | The EP-Dev Whois script        
// |                                           
// | Copyright (c) 2002-2004 Patrick Brown as EP-Dev.com           
// | This program is free software; you can redistribute it and/or modify
// | it under the terms of the GNU General Public License as published by
// | the Free Software Foundation; either version 2 of the License, or
// | (at your option) any later version.              
// | 
// | This program is distributed in the hope that it will be useful,
// | but WITHOUT ANY WARRANTY; without even the implied warranty of
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// | GNU General Public License for more details.
// --------------------------------------------

require_once("config.php");
require_once("templates/language.php");

class WhoisSearch
{
	var $timeout = 30;

	var $domain;
	var $ext;
	var $fulldomain;
	var $var_domain;
	var $var_ext;
	
	var $host;
	var $whois_data;
	var $avail=false;
	var $cost;

	function WhoisSearch()
	{
		global $CONF;
		$timeout = $CONF['timeout'];
	}

	function Check_Domain_Format()
	{
		if (empty($this->domain)) Error_Handle(LANG_ERR_no_domain);

		while (substr($this->domain, -1) == ".")
		{
			$this->domain = substr($this->domain, 0, -1);
		}

		$tdomain = strrchr($this->domain, ".");
		if($tdomain)
			$this->domain = substr($tdomain, 1);
		$this->domain = ereg_replace("[^a-zA-Z0-9-]*([a-zA-Z0-9-]*)[^a-zA-Z0-9-]*", "\\1", $this->domain);

		if (empty($this->domain)) Error_Handle(LANG_ERR_no_domain);
		if (strlen($this->domain.$this->ext) > 67) Error_Handle(LANG_ERR_too_long);
	}

	function lookup($domain, $ext)
	{
		global $NAMESERVERS, $CONF;

		$this->domain = trim($domain);
		$this->ext = trim($ext);
		$this->Check_Domain_Format();
		$this->fulldomain = $this->domain.$this->ext;

		if (array_key_exists($ext, $CONF['domains_cost']))
		{
			$this->cost = $CONF['domains_cost'][$ext] + $CONF['domains_profit'];
		}
		else
		{
			$this->cost = $CONF['default_cost'] + $CONF['domains_profit'];
		}

		$this->cost = FormatNum($this->cost);
		
		$wservers_keys = array_keys($NAMESERVERS['servers']);
		for($i=0; $i<count($wservers_keys); $i++)
		{
			$domain_arr = explode(",", str_replace(" ", "",$NAMESERVERS['servers'][$wservers_keys[$i]]));
			for ($j=0; $j<count($domain_arr); $j++)
			{
				if ($domain_arr[$j] == $ext)
					$this->host = $wservers_keys[$i];
			}
			unset($domain_arr);
		}

		if (!$this->host)
		{
			$lang_return = str_replace("[TLD_EXT]", $ext, LANG_ERR_invalid_reg);
			Error_Handle($lang_return);
		}

		$this->whois_data = "";
		$parts  = array();
		$host   = "";
		
		/* .tv doesn't have a whois database */
		if ($ext == ".tv")
		{
			$this->whois_data = LANG_no_tv_domains;
		}
			$whoisSocket = @fsockopen($this->host,43, $errno, $errstr, $this->timeout);
			
			if ($whoisSocket)
			{
				$extra_args = "";

				/* Query Limit Bypass */
				if (array_key_exists($this->host, $NAMESERVERS['servers_with_special']))
				{
					$data_to_be_sent = $NAMESERVERS['servers_with_special'][$this->host] . $this->domain . $this->ext . "\015\012";
				}

				elseif(in_array($this->host, $NAMESERVERS['servers_with_limits']) && $_GET['page'] != "whois")
				{
					$data_to_be_sent = "is " . $this->domain . $this->ext . "\015\012";
				}
				
				else
				{
					$data_to_be_sent = $this->domain.$this->ext."\015\012";
				}

				fputs($whoisSocket, $data_to_be_sent);
				while (!feof($whoisSocket))
				{
					$this->whois_data .= fgets($whoisSocket,128) . "<br>";
				}
				fclose($whoisSocket);

				if (eregi($NAMESERVERS['keywords'][$this->host], $this->whois_data))
				{
					$this->avail = true;
				}
				else
				{
					$this->avail = false;
				}
			}
			else
			{
				$this->host = LANG_server_error;
				$this->avail = false;
			}
	}
}

/*
	Prints out a price table
*/
function Make_PriceTable()
{
	global $NAMESERVERS, $CONF;

	$tld_count = 0;

	foreach($NAMESERVERS['servers'] as $c_domains)
	{
		$domain_arr = explode(",", str_replace(" ", "",$c_domains));
		foreach ($domain_arr as $c_ext)
		{
			if (!in_array($c_ext, $CONF['price_table_exclude']))
			{
				$dcosts_keys = array_keys($CONF['domains_cost']);
				for($i=0; $i<count($dcosts_keys); $i++)
				{
					if ($c_ext == $dcosts_keys[$i])
					{
						$current_cost=$CONF['domains_cost'][$dcosts_keys[$i]];
					}
				}
				if (!isset($current_cost))
				{
					$current_cost=$CONF['default_cost'];
				}
				$current_cost += $CONF['domains_profit'];
				$tld_data[$tld_count]['tld'] = $c_ext;
				$tld_data[$tld_count]['cost'] = FormatNum($current_cost);
				$tld_count++;
				unset($current_cost);
			}
		}
	}
	return $tld_data;
}

function Get_Extensions()
{
	global $NAMESERVERS, $CONF;

	$i=0;

	foreach($NAMESERVERS['servers'] as $c_domains)
	{
		$domain_arr = explode(",", str_replace(" ", "",$c_domains));
		for ($j=0; $j<count($domain_arr); $j++)
		{
			$output[$i] = $domain_arr[$j];
			$i++;
			//$output .= "<option value=\"".$domain_arr[$j]."\">".$domain_arr[$j]."</option>\n";
		}
	}
	return $output;
}

/*
	This will just format number to be in US... obviously you might be changing this. The format type
	isn't necessary when calling the function as it is no longer in use.
*/
function FormatNum($number, $format_type=1)
{
	global $CONF;
	switch($CONF['currency'])
	{
		case "us": return "\$".number_format($number, 2);
			break;

		case "uk": return "".number_format($number, 2);
			break;
		
		case "eu": return "".number_format($number, 2, ",",".");
			break;
		
		default :
				$values = explode(":", $CONF['currency']);
				return $values[1].number_format($number, $values[2], $values[3], $values[4]);
	}
}
?>